@@ -47,6 +47,7 @@ int loadcfg(const char *cfgfile, const ConfigType type)
 		 {"InterfaceMatchMethod", 0, &cfg.ifacematchmethod, 0, 0},
 		 {"EstimateVisible", 0, &cfg.estimatevisible, 0, 0},
 		 {"EstimateText", cfg.estimatetext, 0, 10, 0},
+		 {"InterfaceOrder", 0, &cfg.interfaceorder, 0, 0},
 		 {"5MinuteHours", 0, &cfg.fiveminutehours, 0, 0},
 		 {"HourlyDays", 0, &cfg.hourlydays, 0, 0},
 		 {"DailyDays", 0, &cfg.dailydays, 0, 0},
@@ -73,6 +74,8 @@ int loadcfg(const char *cfgfile, const ConfigType type)
 		 {"DatabaseWriteAheadLogging", 0, &cfg.waldb, 0, 0},
 		 {"DatabaseSynchronous", 0, &cfg.dbsynchronous, 0, 0},
 		 {"UseUTC", 0, &cfg.useutc, 0, 0},
+		 {"VacuumOnStartup", 0, &cfg.vacuumonstartup, 0, 0},
+		 {"VacuumOnHUPSignal", 0, &cfg.vacuumonhupsignal, 0, 0},
 		 {"HeaderFormat", cfg.hformat, 0, 64, 0},
 		 {"HourlyRate", 0, &cfg.hourlyrate, 0, 0},
 		 {"SummaryRate", 0, &cfg.summaryrate, 0, 0},
@@ -127,7 +130,7 @@ int loadcfg(const char *cfgfile, const ConfigType type)
 			}
 
 			cfglen = (unsigned int)strlen(cset[i].name);
-			if ((linelen < (cfglen + 2)) || (strncasecmp(cfgline, cset[i].name, cfglen) != 0)) {
+			if ((linelen < (cfglen + 2)) || (strncasecmp(cfgline, cset[i].name, cfglen) != 0) || (cfgline[cfglen] != ' ' && cfgline[cfglen] != '=' && cfgline[cfglen] != '\t')) {
 				continue;
 			}
 
@@ -210,6 +213,8 @@ void validatecfg(const ConfigType type)
 	validatebool("DatabaseWriteAheadLogging", &cfg.waldb, WALDB);
 	validateint("DatabaseSynchronous", &cfg.dbsynchronous, DBSYNCHRONOUS, -1, 3);
 	validatebool("UseUTC", &cfg.useutc, USEUTC);
+	validatebool("VacuumOnStartup", &cfg.vacuumonstartup, VACUUMONSTARTUP);
+	validatebool("VacuumOnHUPSignal", &cfg.vacuumonhupsignal, VACUUMONHUPSIGNAL);
 	if (type == CT_Image || type == CT_All) {
 		validatebool("TransparentBg", &cfg.transbg, TRANSBG);
 		validatebool("LargeFonts", &cfg.largefonts, LARGEFONTS);
@@ -233,6 +238,7 @@ void validatecfg(const ConfigType type)
 	validateint("ListTop", &cfg.listtop, LISTTOP, 0, 0);
 	validateint("InterfaceMatchMethod", &cfg.ifacematchmethod, IFACEMATCHMETHOD, 0, 3);
 	validatebool("EstimateVisible", &cfg.estimatevisible, ESTIMATEVISIBLE);
+	validateint("InterfaceOrder", &cfg.interfaceorder, INTERFACEORDER, 0, 1);
 	validateint("5MinuteHours", &cfg.fiveminutehours, FIVEMINUTEHOURS, -1, -1);
 	validateint("HourlyDays", &cfg.hourlydays, HOURLYDAYS, -1, -1);
 	validateint("DailyDays", &cfg.dailydays, DAILYDAYS, -1, -1);
@@ -324,17 +330,6 @@ void validatecfg(const ConfigType type)
 				printf("BarColumnShowsRate and EstimateBarVisible both enabled -> EstimateStyle set to 0\n");
 			}
 		}
-
-		if (cfg.fiveminutehours > 0 && cfg.fivegresultcount > cfg.fiveminutehours * 12) {
-			if (cfg.fiveminutehours * 12 < FIVEGMINRESULTCOUNT) {
-				snprintf(errorstring, 1024, "Value \"%d\" for 5MinuteHours is too small for 5MinuteGraphResultCount with value \"%d\" (smallest supported value: %d). Value for 5MinuteHours needs to be at least %d if 5MinuteGraphResultCount is set to %d.", cfg.fiveminutehours, cfg.fivegresultcount, FIVEGMINRESULTCOUNT, FIVEGMINRESULTCOUNT / 12, FIVEGMINRESULTCOUNT);
-				cfg.fivegresultcount = FIVEGMINRESULTCOUNT;
-			} else {
-				snprintf(errorstring, 1024, "5MinuteGraphResultCount has been adjusted to %d because requested \"%d\" requires more data than can be available with value %d for 5MinuteHours.", cfg.fiveminutehours * 12, cfg.fivegresultcount, cfg.fiveminutehours);
-				cfg.fivegresultcount = cfg.fiveminutehours * 12;
-			}
-			printe(PT_Config);
-		}
 	}
 }
 
@@ -366,6 +361,7 @@ void defaultcfg(void)
 	cfg.ifacematchmethod = IFACEMATCHMETHOD;
 	cfg.estimatevisible = ESTIMATEVISIBLE;
 	strncpy_nt(cfg.estimatetext, ESTIMATETEXT, 10);
+	cfg.interfaceorder = INTERFACEORDER;
 
 	cfg.listfivemins = LISTFIVEMINS;
 	cfg.listhours = LISTHOURS;
@@ -414,6 +410,8 @@ void defaultcfg(void)
 	cfg.waldb = WALDB;
 	cfg.dbsynchronous = DBSYNCHRONOUS;
 	cfg.useutc = USEUTC;
+	cfg.vacuumonstartup = VACUUMONSTARTUP;
+	cfg.vacuumonhupsignal = VACUUMONHUPSIGNAL;
 
 	cfg.transbg = TRANSBG;
 	cfg.largefonts = LARGEFONTS;
