@@ -119,6 +119,10 @@ void printcfgfile(void)
 	defaultcomment(strcmp(cfg.estimatetext, ESTIMATETEXT) == 0);
 	printf("EstimateText \"estimated\"\n\n");
 
+	printf("# interface order (0 = alphabetical by name, 1 = alphabetical by alias)\n");
+	defaultcomment(cfg.interfaceorder == INTERFACEORDER);
+	printf("InterfaceOrder %d\n\n", cfg.interfaceorder);
+
 	printf("\n");
 
 	/* vnstatd section */
@@ -260,6 +264,12 @@ void printcfgfile(void)
 	defaultcomment(cfg.useutc == USEUTC);
 	printf("UseUTC %d\n\n", cfg.useutc);
 
+	printf("# database maintenance (1 = enabled, 0 = disabled)\n");
+	defaultcomment(cfg.vacuumonstartup == VACUUMONSTARTUP);
+	printf("VacuumOnStartup %d\n", cfg.vacuumonstartup);
+	defaultcomment(cfg.vacuumonhupsignal == VACUUMONHUPSIGNAL);
+	printf("VacuumOnHUPSignal %d\n\n", cfg.vacuumonhupsignal);
+
 	printf("\n");
 
 	/* vnstati section */
