@@ -110,6 +110,10 @@ and most can be changed later from the config file.
 #define OSTYLE 3
 #define ESTIMATEBARVISIBLE 1
 
+/* interface order */
+/* 0 = alphabetical by name, 1 = alphabetical by alias */
+#define INTERFACEORDER 0
+
 /* rate in vnstati summary output */
 #define SUMMARYRATE 1
 
@@ -252,6 +256,8 @@ and most can be changed later from the config file.
 #define SLOWDBWARNLIMIT 4.0 // needs to be less than DBREADTIMEOUTSECS
 #define DBSYNCHRONOUS -1
 #define USEUTC 0
+#define VACUUMONSTARTUP 1
+#define VACUUMONHUPSIGNAL 1
 
 /* database read timeout */
 #define DBREADTIMEOUTSECS 5
@@ -330,7 +336,7 @@ typedef struct {
 	int32_t uselogging, createdirs, updatefileowner, bwdetection, bwdetectioninterval, utflocale;
 	int32_t fiveminutehours, hourlydays, dailydays, monthlymonths, yearlyyears, topdayentries;
 	int32_t listfivemins, listhours, listdays, listmonths, listyears, listtop, listjsonxml;
-	int32_t timestampprints, experimental;
+	int32_t timestampprints, interfaceorder, vacuumonstartup, vacuumonhupsignal, experimental;
 } CFG;
 
 /* internal interface information structure */
@@ -388,6 +394,7 @@ extern int debug;
 extern int noexit; /* = running as daemon if 2 */
 extern int intsignal;
 extern int pidfile;
-extern int disableprints;
+extern int disableprinte;
+extern int stderrprinte;
 
 #endif
