@@ -15,6 +15,7 @@ typedef struct {
 } DSTATE;
 
 void daemonize(void);
+void printstartupdetails(void);
 void debugtimestamp(void);
 
 unsigned int addinterfaces(DSTATE *s);
@@ -26,12 +27,11 @@ void filldatabaselist(DSTATE *s);
 void adjustsaveinterval(DSTATE *s);
 void checkdbsaveneed(DSTATE *s);
 void processdatacache(DSTATE *s);
-void processdatalist(DSTATE *s);
 void handleintsignals(DSTATE *s);
-void preparedirs(DSTATE *s);
+void preparedirs(const DSTATE *s);
 void detectboot(DSTATE *s);
 
-int initcachevalues(DSTATE *s, datacache **dc);
+int initcachevalues(const DSTATE *s, datacache **dc);
 int processifinfo(DSTATE *s, datacache **dc);
 void flushcachetodisk(DSTATE *s);
 void handledatabaseerror(DSTATE *s);
