@@ -136,7 +136,7 @@ int drawhours(IMAGECONTENT *ic, const int xpos, const int ypos, const int rate)
 	}
 
 	if (!db_getdata_range(&datalist, &datainfo, ic->interface.name, "hour", 24, buffer, "") || datainfo.count == 0) {
-		gdImageString(ic->im, ic->font, x + (32 * ic->font->w), y + 54, (unsigned char *)"no data available", ic->ctext);
+		gdImageString(ic->im, ic->font, x + (28 * ic->font->w), y + 54 - (ic->large * 18), (unsigned char *)"no hour data available", ic->ctext);
 		return 0;
 	}
 
@@ -666,11 +666,6 @@ void drawsummary(IMAGECONTENT *ic, const int layout, const int rate)
 	imageinit(ic, width, height);
 	layoutinit(ic, "", width, height);
 
-	if (ic->interface.rxtotal == 0 && ic->interface.txtotal == 0) {
-		gdImageString(ic->im, ic->font, 33 * ic->font->w, 100, (unsigned char *)"no data available", ic->ctext);
-		return;
-	}
-
 	drawsummary_alltime(ic, 385 + (ic->large * 125), 57 - headermod + (ic->large * 10));
 	drawlegend(ic, 410 + (ic->large * 132), 155 - headermod + (ic->large * 40), 0);
 
@@ -759,7 +754,8 @@ void drawsummary_digest(IMAGECONTENT *ic, const int x, const int y, const char *
 	}
 
 	if (!db_getdata(&datalist, &datainfo, ic->interface.name, mode, 2) || datalist == NULL) {
-		gdImageString(ic->im, ic->font, 25 * ic->font->w, y + 30, (unsigned char *)"no data available", ic->ctext);
+		snprintf(buffer, 512, "no %s data available", mode);
+		gdImageString(ic->im, ic->font, 20 * ic->font->w, y + 30, (unsigned char *)buffer, ic->ctext);
 		return;
 	} else if (datalist->next == NULL) {
 		data_current = datalist;
@@ -941,8 +937,8 @@ int drawfiveminutes(IMAGECONTENT *ic, const int xpos, const int ypos, const int
 	}
 
 	if (!db_getdata(&datalist, &datainfo, ic->interface.name, "fiveminute", (uint32_t)resultcount) || datainfo.count == 0) {
-		x = (resultcount + FIVEMINEXTRASPACE + (ic->large * 14)) / 2 - (8 * ic->font->w + ic->font->w / 2);
-		gdImageString(ic->im, ic->font, x, y - (height / 2) - ic->font->h, (unsigned char *)"no data available", ic->ctext);
+		x = (resultcount + FIVEMINEXTRASPACE + (ic->large * 14)) / 2 - (13 * ic->font->w);
+		gdImageString(ic->im, ic->font, x, y - (height / 2) - ic->font->h, (unsigned char *)"no 5 minute data available", ic->ctext);
 		return 0;
 	}
 
