@@ -16,7 +16,8 @@ void initparams(PARAMS *p)
 	db = NULL;
 	noexit = 0;		   /* allow functions to exit in case of error */
 	debug = 0;		   /* debug disabled by default */
-	disableprints = 0; /* let prints be visible */
+	disableprinte = 0; /* let printe() output be visible */
+	stderrprinte = 0;  /* use stdout for printe() output */
 
 	p->addiface = 0;
 	p->query = 1;
@@ -53,7 +54,7 @@ void initparams(PARAMS *p)
 	defaultcfg();
 }
 
-void showhelp(PARAMS *p)
+void showhelp(const PARAMS *p)
 {
 	printf("vnStat %s by Teemu Toivola <tst at iki dot fi>\n\n", getversion());
 
@@ -85,7 +86,7 @@ void showhelp(PARAMS *p)
 	printf("Use \"--longhelp\" or \"man vnstat\" for complete list of options.\n");
 }
 
-void showlonghelp(PARAMS *p)
+void showlonghelp(const PARAMS *p)
 {
 	printf("vnStat %s by Teemu Toivola <tst at iki dot fi>\n\n", getversion());
 
@@ -531,7 +532,7 @@ void parseargs(PARAMS *p, const int argc, char **argv)
 				p->alert = 1;
 			}
 		} else if ((strcmp(argv[currentarg], "-v") == 0) || (strcmp(argv[currentarg], "--version") == 0)) {
-			printf("vnStat %s by Teemu Toivola <tst at iki dot fi>\n", getversion());
+			printf("vnStat %s by Teemu Toivola <tst at iki dot fi> (SQLite %s)\n", getversion(), sqlite3_libversion());
 			exit(EXIT_SUCCESS);
 		} else {
 			if (argv[currentarg][0] == '-' || strlen(argv[currentarg]) == 1) {
@@ -814,7 +815,7 @@ void handleshowalert(PARAMS *p)
 	exit(EXIT_SUCCESS);
 }
 
-void handleremoveinterface(PARAMS *p)
+void handleremoveinterface(const PARAMS *p)
 {
 	if (!p->removeiface) {
 		return;
@@ -856,7 +857,7 @@ void handleremoveinterface(PARAMS *p)
 	}
 }
 
-void handlerenameinterface(PARAMS *p)
+void handlerenameinterface(const PARAMS *p)
 {
 	if (!p->renameiface) {
 		return;
@@ -965,7 +966,7 @@ void handleaddinterface(PARAMS *p)
 	}
 }
 
-void handlesetalias(PARAMS *p)
+void handlesetalias(const PARAMS *p)
 {
 	if (!p->setalias) {
 		return;
