@@ -1,5 +1,5 @@
 /*
-vnStat daemon - Copyright (C) 2008-2022 Teemu Toivola <tst@iki.fi>
+vnStat daemon - Copyright (C) 2008-2023 Teemu Toivola <tst@iki.fi>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ int main(int argc, char *argv[])
 		for (currentarg = 1; currentarg < argc; currentarg++) {
 			if ((strcmp(argv[currentarg], "-D") == 0) || (strcmp(argv[currentarg], "--debug") == 0)) {
 				debug = 1;
-				printf("Debug enabled, vnstatd %s\n", VERSION);
+				printf("Debug enabled, vnstatd %s, SQLite %s\n", VERSION, sqlite3_libversion());
 			} else if (strcmp(argv[currentarg], "--config") == 0) {
 				if (currentarg + 1 < argc) {
 					strncpy_nt(s.cfgfile, argv[currentarg + 1], 512);
@@ -95,12 +95,38 @@ int main(int argc, char *argv[])
 	detectboot(&s);
 	preparedatabase(&s);
 
-	if (!db_removeoldentries()) {
-		printf("Error: Database \"%s/%s\" cleanup failed: %s\n", cfg.dbdir, DATABASEFILE, strerror(errno));
+	if (cfg.fiveminutehours == 0 && cfg.hourlydays == 0 && cfg.dailydays == 0 && cfg.monthlymonths == 0 && cfg.yearlyyears == 0 && cfg.topdayentries == 0) {
+		printf("Error: All data resolutions have been disabled in data retention configuration:");
+		printf("  5MinuteHours   %d\n", cfg.fiveminutehours);
+		printf("  HourlyDays     %d\n", cfg.hourlydays);
+		printf("  DailyDays      %d\n", cfg.dailydays);
+		printf("  MonthlyMonths  %d\n", cfg.monthlymonths);
+		printf("  YearlyYears    %d\n", cfg.yearlyyears);
+		printf("  TopDayEntries  %d\n", cfg.topdayentries);
 		printf("Exiting...\n");
 		exit(EXIT_FAILURE);
 	}
 
+	if (!db_removeoldentries()) {
+		printf("Error: Database \"%s/%s\" old entry cleanup failed: %s\n", cfg.dbdir, DATABASEFILE, strerror(errno));
+		printf("Exiting...\n");
+		exit(EXIT_FAILURE);
+	}
+
+	if (!db_removedisabledresolutionentries()) {
+		printf("Error: Database \"%s/%s\" disabled resolution entry cleanup failed: %s\n", cfg.dbdir, DATABASEFILE, strerror(errno));
+		printf("Exiting...\n");
+		exit(EXIT_FAILURE);
+	}
+
+	if (cfg.vacuumonstartup) {
+		if (!db_vacuum()) {
+			printf("Error: Database \"%s/%s\" vacuum failed: %s\n", cfg.dbdir, DATABASEFILE, strerror(errno));
+			printf("Exiting...\n");
+			exit(EXIT_FAILURE);
+		}
+	}
+
 	setsignaltraps();
 
 	/* start as daemon if requested, debug can't be enabled at the same time */
@@ -122,23 +148,7 @@ int main(int argc, char *argv[])
 	timeused_debug("daemon_startup", 0);
 	s.running = 1;
 
-#if defined(__linux__) && HAVE_LINUX_RTNETLINK_H
-#if HAVE_DECL_IFLA_STATS64
-	snprintf(errorstring, 1024, "vnStat daemon %s started. (pid:%d uid:%d gid:%d 64-bit)", getversion(), (int)getpid(), (int)getuid(), (int)getgid());
-#else
-	snprintf(errorstring, 1024, "vnStat daemon %s started. (pid:%d uid:%d gid:%d 32-bit)", getversion(), (int)getpid(), (int)getuid(), (int)getgid());
-#endif
-#else
-	snprintf(errorstring, 1024, "vnStat daemon %s started. (pid:%d uid:%d gid:%d)", getversion(), (int)getpid(), (int)getuid(), (int)getgid());
-#endif
-	printe(PT_Info);
-
-#if !HAVE_DECL_SQLITE_CHECKPOINT_RESTART
-	if (cfg.waldb) {
-		snprintf(errorstring, 1024, "DatabaseWriteAheadLogging is enabled but used libsqlite3 does not support it");
-		printe(PT_Warning);
-	}
-#endif
+	printstartupdetails();
 
 	/* warmup */
 	if (s.dbifcount == 0) {
@@ -326,7 +336,7 @@ void parseargs(DSTATE *s, int argc, char **argv)
 			s->initdb = 1;
 			s->showhelp = 0;
 		} else if ((strcmp(argv[currentarg], "-v") == 0) || (strcmp(argv[currentarg], "--version") == 0)) {
-			printf("vnStat daemon %s by Teemu Toivola <tst at iki dot fi>\n", getversion());
+			printf("vnStat daemon %s by Teemu Toivola <tst at iki dot fi> (SQLite %s)\n", getversion(), sqlite3_libversion());
 			exit(EXIT_SUCCESS);
 		} else if ((strcmp(argv[currentarg], "-p") == 0) || (strcmp(argv[currentarg], "--pidfile") == 0)) {
 			if (currentarg + 1 < argc) {
