@@ -1,5 +1,5 @@
 /*
-vnStat image output - Copyright (C) 2007-2022 Teemu Toivola <tst@iki.fi>
+vnStat image output - Copyright (C) 2007-2023 Teemu Toivola <tst@iki.fi>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ int main(int argc, char *argv[])
 		for (currentarg = 1; currentarg < argc; currentarg++) {
 			if ((strcmp(argv[currentarg], "-D") == 0) || (strcmp(argv[currentarg], "--debug") == 0)) {
 				debug = 1;
-				printf("Debug enabled, vnstati %s, LibGD %d.%d.%d\n", VERSION, GD_MAJOR_VERSION, GD_MINOR_VERSION, GD_RELEASE_VERSION);
+				printf("Debug enabled, vnstati %s, SQLite %s, LibGD %d.%d.%d\n", VERSION, sqlite3_libversion(), GD_MAJOR_VERSION, GD_MINOR_VERSION, GD_RELEASE_VERSION);
 			} else if (strcmp(argv[currentarg], "--config") == 0) {
 				if (currentarg + 1 < argc) {
 					strncpy_nt(p.cfgfile, argv[currentarg + 1], 512);
@@ -48,7 +48,7 @@ int main(int argc, char *argv[])
 					}
 					currentarg++;
 				} else {
-					printf("Error: File for --config missing.\n");
+					fprintf(stderr, "Error: File for --config missing.\n");
 					return 1;
 				}
 			}
@@ -89,7 +89,7 @@ int main(int argc, char *argv[])
 	writeoutput(&p, &ic);
 
 	if (debug)
-		printf("all done\n");
+		printf("File written, all done\n");
 
 	return 0;
 }
@@ -99,7 +99,8 @@ void initiparams(IPARAMS *p)
 	db = NULL;
 	noexit = 0;		   /* allow functions to exit in case of error */
 	debug = 0;		   /* debug disabled by default */
-	disableprints = 0; /* let prints be visible */
+	disableprinte = 0; /* let printe() output be visible */
+	stderrprinte = 1;  /* use stderr for printe() output to avoid corrupting "-o -" content */
 
 	p->interface[0] = '\0';
 	p->filename[0] = '\0';
@@ -112,7 +113,7 @@ void initiparams(IPARAMS *p)
 	defaultcfg();
 }
 
-void showihelp(IPARAMS *p)
+void showihelp(const IPARAMS *p)
 {
 	printf("vnStat image output %s by Teemu Toivola <tst at iki dot fi>\n\n", getversion());
 
@@ -183,12 +184,12 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc) {
 				if (strchr(argv[currentarg + 1], '+') != NULL) {
 					if (strlen(argv[currentarg + 1]) > MAXIFPARAMLEN - 1) {
-						printf("Error: Interface merge is limited to %d characters.\n", MAXIFPARAMLEN - 1);
+						fprintf(stderr, "Error: Interface merge is limited to %d characters.\n", MAXIFPARAMLEN - 1);
 						exit(EXIT_FAILURE);
 					}
 				} else {
 					if (strlen(argv[currentarg + 1]) > MAXIFLEN - 1) {
-						printf("Error: Interface name is limited to %d characters.\n", MAXIFLEN - 1);
+						fprintf(stderr, "Error: Interface name is limited to %d characters.\n", MAXIFLEN - 1);
 						exit(EXIT_FAILURE);
 					}
 				}
@@ -197,7 +198,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 					printf("Used interface: \"%s\"\n", p->interface);
 				currentarg++;
 			} else {
-				printf("Error: Interface for %s missing.\n", argv[currentarg]);
+				fprintf(stderr, "Error: Interface for %s missing.\n", argv[currentarg]);
 				exit(EXIT_FAILURE);
 			}
 		} else if ((strcmp(argv[currentarg], "-o") == 0) || (strcmp(argv[currentarg], "--output")) == 0) {
@@ -207,7 +208,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 					printf("Output file: \"%s\"\n", p->filename);
 				currentarg++;
 			} else {
-				printf("Error: Filename for %s missing.\n", argv[currentarg]);
+				fprintf(stderr, "Error: Filename for %s missing.\n", argv[currentarg]);
 				exit(EXIT_FAILURE);
 			}
 		} else if ((strcmp(argv[currentarg], "-c") == 0) || (strcmp(argv[currentarg], "--cache")) == 0) {
@@ -217,21 +218,21 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 					printf("Cache time: %d minutes\n", p->cache);
 				currentarg++;
 			} else {
-				printf("Error: Parameter for %s missing or invalid.\n", argv[currentarg]);
+				fprintf(stderr, "Error: Parameter for %s missing or invalid.\n", argv[currentarg]);
 				exit(EXIT_FAILURE);
 			}
 		} else if ((strcmp(argv[currentarg], "--style")) == 0) {
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
 				cfg.ostyle = atoi(argv[currentarg + 1]);
 				if (cfg.ostyle > 3 || cfg.ostyle < 0) {
-					printf("Error: Invalid style parameter \"%d\" for --style.\n", cfg.ostyle);
+					fprintf(stderr, "Error: Invalid style parameter \"%d\" for --style.\n", cfg.ostyle);
 					exit(EXIT_FAILURE);
 				}
 				if (debug)
 					printf("Style changed: %d\n", cfg.ostyle);
 				currentarg++;
 			} else {
-				printf("Error: Style parameter for --style missing.\n");
+				fprintf(stderr, "Error: Style parameter for --style missing.\n");
 				exit(EXIT_FAILURE);
 			}
 		} else if ((strcmp(argv[currentarg], "--scale")) == 0) {
@@ -239,25 +240,25 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
 				cfg.imagescale = atoi(argv[currentarg + 1]);
 				if (cfg.imagescale > 500 || cfg.imagescale < 50) {
-					printf("Error: Invalid parameter \"%d\" for --scale. Supported value range: 50 <= N <= 500\n", cfg.imagescale);
+					fprintf(stderr, "Error: Invalid parameter \"%d\" for --scale. Supported value range: 50 <= N <= 500\n", cfg.imagescale);
 					exit(EXIT_FAILURE);
 				}
 				if (debug)
 					printf("Scale changed: %d\n", cfg.imagescale);
 				currentarg++;
 			} else {
-				printf("Error: Percent parameter for --scale missing.\n");
+				fprintf(stderr, "Error: Percent parameter for --scale missing.\n");
 				exit(EXIT_FAILURE);
 			}
 #else
-			printf("Error: Function needed by --scale is not available in used LibGD %d.%d.%d.\n", GD_MAJOR_VERSION, GD_MINOR_VERSION, GD_RELEASE_VERSION);
+			fprintf(stderr, "Error: Function needed by --scale is not available in used LibGD %d.%d.%d.\n", GD_MAJOR_VERSION, GD_MINOR_VERSION, GD_RELEASE_VERSION);
 			exit(EXIT_FAILURE);
 #endif
 		} else if ((strcmp(argv[currentarg], "--transparent")) == 0) {
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
 				cfg.transbg = atoi(argv[currentarg + 1]);
 				if (cfg.transbg > 1 || cfg.transbg < 0) {
-					printf("Error: Invalid parameter \"%d\" for --transparent.\n", cfg.transbg);
+					fprintf(stderr, "Error: Invalid parameter \"%d\" for --transparent.\n", cfg.transbg);
 					exit(EXIT_FAILURE);
 				}
 				if (debug)
@@ -275,7 +276,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 					printf("DatabaseDir: \"%s\"\n", cfg.dbdir);
 				currentarg++;
 			} else {
-				printf("Error: Directory for --dbdir missing.\n");
+				fprintf(stderr, "Error: Directory for --dbdir missing.\n");
 				exit(EXIT_FAILURE);
 			}
 		} else if ((strcmp(argv[currentarg], "--locale")) == 0) {
@@ -285,7 +286,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 					printf("Locale: \"%s\"\n", argv[currentarg + 1]);
 				currentarg++;
 			} else {
-				printf("Error: Locale for --locale missing.\n");
+				fprintf(stderr, "Error: Locale for --locale missing.\n");
 				exit(EXIT_FAILURE);
 			}
 		} else if (strcmp(argv[currentarg], "--config") == 0) {
@@ -298,7 +299,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 					printf("Header text: \"%s\"\n", ic->headertext);
 				currentarg++;
 			} else {
-				printf("Error: Text string parameter for --headertext missing.\n");
+				fprintf(stderr, "Error: Text string parameter for --headertext missing.\n");
 				exit(EXIT_FAILURE);
 			}
 		} else if (strcmp(argv[currentarg], "--altdate") == 0) {
@@ -314,7 +315,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
 				cfg.listdays = atoi(argv[currentarg + 1]);
 				if (cfg.listdays < 0) {
-					printf("Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
+					fprintf(stderr, "Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
 					exit(EXIT_FAILURE);
 				}
 				currentarg++;
@@ -324,7 +325,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
 				cfg.listmonths = atoi(argv[currentarg + 1]);
 				if (cfg.listmonths < 0) {
-					printf("Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
+					fprintf(stderr, "Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
 					exit(EXIT_FAILURE);
 				}
 				currentarg++;
@@ -334,7 +335,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
 				cfg.listtop = atoi(argv[currentarg + 1]);
 				if (cfg.listtop < 0) {
-					printf("Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
+					fprintf(stderr, "Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
 					exit(EXIT_FAILURE);
 				}
 				currentarg++;
@@ -344,7 +345,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
 				cfg.listyears = atoi(argv[currentarg + 1]);
 				if (cfg.listyears < 0) {
-					printf("Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
+					fprintf(stderr, "Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
 					exit(EXIT_FAILURE);
 				}
 				currentarg++;
@@ -354,7 +355,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
 				cfg.listhours = atoi(argv[currentarg + 1]);
 				if (cfg.listhours < 0) {
-					printf("Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
+					fprintf(stderr, "Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
 					exit(EXIT_FAILURE);
 				}
 				currentarg++;
@@ -364,7 +365,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
 				cfg.listfivemins = atoi(argv[currentarg + 1]);
 				if (cfg.listfivemins < 0) {
-					printf("Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
+					fprintf(stderr, "Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
 					exit(EXIT_FAILURE);
 				}
 				currentarg++;
@@ -376,7 +377,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc && (strlen(argv[currentarg + 1]) == 1 || ishelprequest(argv[currentarg + 1]))) {
 				if (!isdigit(argv[currentarg + 1][0]) || atoi(argv[currentarg + 1]) > 1 || atoi(argv[currentarg + 1]) < 0) {
 					if (!ishelprequest(argv[currentarg + 1]))
-						printf("Error: Invalid mode selection \"%s\".\n", argv[currentarg + 1]);
+						fprintf(stderr, "Error: Invalid mode selection \"%s\".\n", argv[currentarg + 1]);
 					printf(" Valid modes for %s:\n", argv[currentarg]);
 					printf("    0 - 24 hour sliding windows\n");
 					printf("    1 - graph start from midnight\n");
@@ -392,10 +393,10 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
 				cfg.fivegresultcount = atoi(argv[currentarg + 1]);
 				if (cfg.fivegresultcount < FIVEGMINRESULTCOUNT) {
-					printf("Error: Invalid limit parameter \"%s\" for %s. A value equal or over %d is expected.\n", argv[currentarg + 1], argv[currentarg], FIVEGMINRESULTCOUNT);
+					fprintf(stderr, "Error: Invalid limit parameter \"%s\" for %s. A value equal or over %d is expected.\n", argv[currentarg + 1], argv[currentarg], FIVEGMINRESULTCOUNT);
 					exit(EXIT_FAILURE);
 				} else if (cfg.fivegresultcount > cfg.fiveminutehours * 12 && cfg.fiveminutehours > 0) {
-					printf("Error: Invalid limit parameter \"%s\" for %s. Value cannot be larger than configured data retention (5MinuteHours %d * 12 = %d).\n", argv[currentarg + 1], argv[currentarg], cfg.fiveminutehours, cfg.fiveminutehours * 12);
+					fprintf(stderr, "Error: Invalid limit parameter \"%s\" for %s. Value cannot be larger than configured data retention (5MinuteHours %d * 12 = %d).\n", argv[currentarg + 1], argv[currentarg], cfg.fiveminutehours, cfg.fiveminutehours * 12);
 					exit(EXIT_FAILURE);
 				}
 				currentarg++;
@@ -403,7 +404,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
 				cfg.fivegheight = atoi(argv[currentarg + 1]);
 				if (cfg.fivegheight < FIVEGMINHEIGHT) {
-					printf("Error: Invalid height parameter \"%s\" for %s. A value equal or over %d is expected.\n", argv[currentarg + 1], argv[currentarg], FIVEGMINHEIGHT);
+					fprintf(stderr, "Error: Invalid height parameter \"%s\" for %s. A value equal or over %d is expected.\n", argv[currentarg + 1], argv[currentarg], FIVEGMINHEIGHT);
 					exit(EXIT_FAILURE);
 				}
 				currentarg++;
@@ -413,7 +414,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc && (strlen(argv[currentarg + 1]) == 1 || ishelprequest(argv[currentarg + 1]))) {
 				if (!isdigit(argv[currentarg + 1][0]) || atoi(argv[currentarg + 1]) > 1 || atoi(argv[currentarg + 1]) < 0) {
 					if (!ishelprequest(argv[currentarg + 1]))
-						printf("Error: Invalid graph selection \"%s\".\n", argv[currentarg + 1]);
+						fprintf(stderr, "Error: Invalid graph selection \"%s\".\n", argv[currentarg + 1]);
 					printf(" Valid graphs for %s:\n", argv[currentarg]);
 					printf("    0 - hours\n");
 					printf("    1 - 5 minutes\n");
@@ -429,7 +430,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc && (strlen(argv[currentarg + 1]) == 1 || ishelprequest(argv[currentarg + 1]))) {
 				if (!isdigit(argv[currentarg + 1][0]) || atoi(argv[currentarg + 1]) > 1 || atoi(argv[currentarg + 1]) < 0) {
 					if (!ishelprequest(argv[currentarg + 1]))
-						printf("Error: Invalid graph selection \"%s\".\n", argv[currentarg + 1]);
+						fprintf(stderr, "Error: Invalid graph selection \"%s\".\n", argv[currentarg + 1]);
 					printf(" Valid graphs for %s:\n", argv[currentarg]);
 					printf("    0 - hours\n");
 					printf("    1 - 5 minutes\n");
@@ -450,7 +451,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			if (currentarg + 1 < argc && (strlen(argv[currentarg + 1]) == 1 || ishelprequest(argv[currentarg + 1]))) {
 				if (!isdigit(argv[currentarg + 1][0]) || atoi(argv[currentarg + 1]) > 1 || atoi(argv[currentarg + 1]) < 0) {
 					if (!ishelprequest(argv[currentarg + 1]))
-						printf("Error: Invalid parameter \"%s\".\n", argv[currentarg + 1]);
+						fprintf(stderr, "Error: Invalid parameter \"%s\".\n", argv[currentarg + 1]);
 					printf(" Valid parameters for %s:\n", argv[currentarg]);
 					printf("    0 - bytes\n");
 					printf("    1 - bits\n");
@@ -468,41 +469,41 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 		} else if ((strcmp(argv[currentarg], "-b") == 0) || (strcmp(argv[currentarg], "--begin") == 0)) {
 			if (currentarg + 1 < argc) {
 				if (!validatedatetime(argv[currentarg + 1])) {
-					printf("Error: Invalid date format, expected YYYY-MM-DD HH:MM, YYYY-MM-DD or \"today\".\n");
+					fprintf(stderr, "Error: Invalid date format, expected YYYY-MM-DD HH:MM, YYYY-MM-DD or \"today\".\n");
 					exit(EXIT_FAILURE);
 				}
 				strncpy_nt(ic->databegin, argv[currentarg + 1], 18);
 				currentarg++;
 			} else {
-				printf("Error: Date of format YYYY-MM-DD HH:MM, YYYY-MM-DD or \"today\" for %s missing.\n", argv[currentarg]);
+				fprintf(stderr, "Error: Date of format YYYY-MM-DD HH:MM, YYYY-MM-DD or \"today\" for %s missing.\n", argv[currentarg]);
 				exit(EXIT_FAILURE);
 			}
 		} else if ((strcmp(argv[currentarg], "-e") == 0) || (strcmp(argv[currentarg], "--end") == 0)) {
 			if (currentarg + 1 < argc) {
 				if (!validatedatetime(argv[currentarg + 1])) {
-					printf("Error: Invalid date format, expected YYYY-MM-DD HH:MM or YYYY-MM-DD.\n");
+					fprintf(stderr, "Error: Invalid date format, expected YYYY-MM-DD HH:MM or YYYY-MM-DD.\n");
 					exit(EXIT_FAILURE);
 				}
 				strncpy_nt(ic->dataend, argv[currentarg + 1], 18);
 				currentarg++;
 			} else {
-				printf("Error: Date of format YYYY-MM-DD HH:MM or YYYY-MM-DD for %s missing.\n", argv[currentarg]);
+				fprintf(stderr, "Error: Date of format YYYY-MM-DD HH:MM or YYYY-MM-DD for %s missing.\n", argv[currentarg]);
 				exit(EXIT_FAILURE);
 			}
 		} else if (strcmp(argv[currentarg], "--limit") == 0) {
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
 				p->limit = atoi(argv[currentarg + 1]);
 				if (p->limit < 0) {
-					printf("Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
+					fprintf(stderr, "Error: Invalid limit parameter \"%s\" for %s. Only a zero and positive numbers are allowed.\n", argv[currentarg + 1], argv[currentarg]);
 					exit(EXIT_FAILURE);
 				}
 				currentarg++;
 			} else {
-				printf("Error: Invalid or missing parameter for %s.\n", argv[currentarg]);
+				fprintf(stderr, "Error: Invalid or missing parameter for %s.\n", argv[currentarg]);
 				exit(EXIT_FAILURE);
 			}
 		} else if ((strcmp(argv[currentarg], "-v") == 0) || (strcmp(argv[currentarg], "--version")) == 0) {
-			printf("vnStat image output %s by Teemu Toivola <tst at iki dot fi> (LibGD %d.%d.%d)\n", getversion(), GD_MAJOR_VERSION, GD_MINOR_VERSION, GD_RELEASE_VERSION);
+			printf("vnStat image output %s by Teemu Toivola <tst at iki dot fi> (SQLite %s, LibGD %d.%d.%d)\n", getversion(), sqlite3_libversion(), GD_MAJOR_VERSION, GD_MINOR_VERSION, GD_RELEASE_VERSION);
 			exit(EXIT_SUCCESS);
 		} else {
 			if (argv[currentarg][0] == '-') {
@@ -511,12 +512,12 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			} else {
 				if (strchr(argv[currentarg], '+') != NULL) {
 					if (strlen(argv[currentarg]) > MAXIFPARAMLEN - 1) {
-						printf("Error: Interface merge is limited to %d characters.\n", MAXIFPARAMLEN - 1);
+						fprintf(stderr, "Error: Interface merge is limited to %d characters.\n", MAXIFPARAMLEN - 1);
 						exit(EXIT_FAILURE);
 					}
 				} else {
 					if (strlen(argv[currentarg]) > MAXIFLEN - 1) {
-						printf("Error: Interface name is limited to %d characters.\n", MAXIFLEN - 1);
+						fprintf(stderr, "Error: Interface name is limited to %d characters.\n", MAXIFLEN - 1);
 						exit(EXIT_FAILURE);
 					}
 				}
@@ -547,16 +548,19 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 	}
 }
 
-void validateinput(IPARAMS *p)
+void validateinput(const IPARAMS *p)
 {
 	if (!cfg.qmode || !strlen(p->filename)) {
-		printf("At least output mode and file parameter needs to be given. ");
-		printf("Use -? or --help for getting short help.\n");
+		fprintf(stderr, "Error: At least output mode and file parameter needs to be given. ");
+		fprintf(stderr, "Use -? or --help for getting short help.\n");
+		exit(EXIT_FAILURE);
+	} else if (debug && strlen(p->filename) == 1 && p->filename[0] == '-') {
+		fprintf(stderr, "Error: Use of -D / --debug in combination with stdout file output isn't supported.\n");
 		exit(EXIT_FAILURE);
 	}
 }
 
-void handlecaching(IPARAMS *p, IMAGECONTENT *ic)
+void handlecaching(const IPARAMS *p, const IMAGECONTENT *ic)
 {
 	struct stat filestat;
 
@@ -573,7 +577,7 @@ void handlecaching(IPARAMS *p, IMAGECONTENT *ic)
 	} else {
 		/* abort if error is something else than file not found */
 		if (errno != ENOENT) {
-			printf("Error: Getting status for file \"%s\" failed: %s (%d)\n", p->filename, strerror(errno), errno);
+			fprintf(stderr, "Error: Getting status for file \"%s\" failed: %s (%d)\n", p->filename, strerror(errno), errno);
 			exit(EXIT_FAILURE);
 		}
 	}
@@ -585,7 +589,7 @@ void handledatabase(IPARAMS *p, IMAGECONTENT *ic)
 	iflist *dbifl = NULL;
 
 	if (!db_open_ro()) {
-		printf("Error: Failed to open database \"%s/%s\" in read-only mode.\n", cfg.dbdir, DATABASEFILE);
+		fprintf(stderr, "Error: Failed to open database \"%s/%s\" in read-only mode.\n", cfg.dbdir, DATABASEFILE);
 		exit(EXIT_FAILURE);
 	}
 	if (strlen(p->interface)) {
@@ -601,17 +605,17 @@ void handledatabase(IPARAMS *p, IMAGECONTENT *ic)
 					}
 				}
 				if (!found) {
-					printf("Error: No interface matching \"%s\" found in database.\n", p->interface);
+					fprintf(stderr, "Error: No interface matching \"%s\" found in database.\n", p->interface);
 					exit(EXIT_FAILURE);
 				}
 			} else {
-				printf("Error: Not all requested interfaces found in database or given interfaces aren't unique.\n");
+				fprintf(stderr, "Error: Not all requested interfaces found in database or given interfaces aren't unique.\n");
 				exit(EXIT_FAILURE);
 			}
 		}
 	} else {
 		if (db_getiflist_sorted(&dbifl, 1) <= 0) {
-			printf("Error: Unable to discover suitable interface from database.\n");
+			fprintf(stderr, "Error: Unable to discover suitable interface from database.\n");
 			exit(EXIT_FAILURE);
 		}
 		strncpy_nt(p->interface, dbifl->interface, MAXIFLEN);
@@ -620,18 +624,18 @@ void handledatabase(IPARAMS *p, IMAGECONTENT *ic)
 			printf("Automatically selected interface: \"%s\"\n", p->interface);
 	}
 	if (!db_getinterfaceinfo(p->interface, &ic->interface)) {
-		printf("Error: Failed to fetch interface \"%s\" details from database.\n", p->interface);
+		fprintf(stderr, "Error: Failed to fetch interface \"%s\" details from database.\n", p->interface);
 		exit(EXIT_FAILURE);
 	}
 }
 
-void validateoutput(IPARAMS *p)
+void validateoutput(const IPARAMS *p)
 {
 #if HAVE_DECL_GDIMAGEFILE
 	/* not output to stdout */
 	if (!(strlen(p->filename) == 1 && p->filename[0] == '-')) {
 		if (!gdSupportsFileType(p->filename, 1)) {
-			printf("Error: Image format file extension for \"%s\" is not supported or recognized\n\n", p->filename);
+			fprintf(stderr, "Error: Image format file extension for \"%s\" is not supported or recognized\n\n", p->filename);
 			showsupportedfileextensions();
 			exit(EXIT_FAILURE);
 		}
@@ -639,7 +643,7 @@ void validateoutput(IPARAMS *p)
 #else
 	/* show warning if given filename doesn't end with .png when gdImageFile() isn't available */
 	if (!(strlen(p->filename) >= 4 && strcmp(p->filename + strlen(p->filename) - 4, ".png") == 0)) {
-		printf("Warning: Image format selection based on file extension is not available in used LibGD %d.%d.%d, \"%s\" will be written as png.\n", GD_MAJOR_VERSION, GD_MINOR_VERSION, GD_RELEASE_VERSION, p->filename);
+		fprintf(stderr, "Warning: Image format selection based on file extension is not available in used LibGD %d.%d.%d, \"%s\" will be written as png.\n", GD_MAJOR_VERSION, GD_MINOR_VERSION, GD_RELEASE_VERSION, p->filename);
 	}
 #endif
 }
@@ -653,7 +657,7 @@ void writeoutput(IPARAMS *p, IMAGECONTENT *ic)
 	/* output to stdout is always png */
 	if (strlen(p->filename) == 1 && p->filename[0] == '-') {
 		if ((p->pngout = fdopen(1, "w")) == NULL) {
-			printf("Error: Opening stdout for output failed: %s\n", strerror(errno));
+			fprintf(stderr, "Error: Opening stdout for output failed: %s\n", strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 		gdImagePng(ic->im, p->pngout);
@@ -665,12 +669,12 @@ void writeoutput(IPARAMS *p, IMAGECONTENT *ic)
 			gdImagePaletteToTrueColor(ic->im);
 		}
 		if (!gdImageFile(ic->im, p->filename)) {
-			printf("Error: Writing output to \"%s\" failed: %s\n", p->filename, strerror(errno));
+			fprintf(stderr, "Error: Writing output to \"%s\" failed: %s\n", p->filename, strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 #else
 		if ((p->pngout = fopen(p->filename, "w")) == NULL) {
-			printf("Error: Opening file \"%s\" for output failed: %s\n", p->filename, strerror(errno));
+			fprintf(stderr, "Error: Opening file \"%s\" for output failed: %s\n", p->filename, strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 		gdImagePng(ic->im, p->pngout);
